@@ -77,9 +77,13 @@ def main():
 
         # 1. Load Model
         config = MultimodalConfig(
-            vocab_size=50257,
-            vision_encoder="vit",
-            fusion_type="cross_attention"
+            vocab_size=1000,      # Small vocab for demo
+            vision_encoder="vit", # Use ViT but smaller
+            image_size=64,        # Very small images for demo
+            fusion_type="cross_attention",
+            hidden_size=128,      # Smaller model
+            num_hidden_layers=2,  # Fewer layers
+            num_diffusion_steps=3 # Fewer steps
         )
         model = DiffusionTransformer(config)
         model.eval()
